package com.ruoyi.web.controller.business.giveDetail;

import java.util.List;
import java.util.Objects;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.fastjson2.JSON;
import lombok.extern.slf4j.Slf4j;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.giveDetail.TbGiveDetail;
import com.ruoyi.system.service.giveDetail.ITbGiveDetailService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 服务发放明细Controller
 * 
 * @author ruoyi
 * @date 2024-09-24
 */
@Slf4j
@RestController
@RequestMapping("/system/detail")
public class TbGiveDetailController extends BaseController
{
    @Autowired
    private ITbGiveDetailService tbGiveDetailService;

    /**
     * 查询服务发放明细列表
     */
    @PreAuthorize("@ss.hasPermi('system:detail:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbGiveDetail tbGiveDetail)
    {
        startPage();
        List<TbGiveDetail> list = tbGiveDetailService.selectTbGiveDetailList(tbGiveDetail);
        return getDataTable(list);
    }

    /**
     * 导出服务发放明细列表
     */
    @PreAuthorize("@ss.hasPermi('system:detail:export')")
    @Log(title = "服务发放明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbGiveDetail tbGiveDetail)
    {
        log.info("导出服务发放明细列表入参:{}", JSON.toJSON(tbGiveDetail));
        List<TbGiveDetail> list = tbGiveDetailService.selectTbGiveDetailList(tbGiveDetail);
        ExcelUtil<TbGiveDetail> util = new ExcelUtil<TbGiveDetail>(TbGiveDetail.class);
        util.exportExcel(response, list, "服务发放明细数据");
    }

    /**
     * 获取服务发放明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:detail:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tbGiveDetailService.selectTbGiveDetailById(id));
    }

    /**
     * 新增服务发放明细
     */
    @PreAuthorize("@ss.hasPermi('system:detail:add')")
    @Log(title = "服务发放明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbGiveDetail tbGiveDetail)
    {
        return toAjax(tbGiveDetailService.insertTbGiveDetail(tbGiveDetail));
    }

    /**
     * 修改服务发放明细
     */
    @PreAuthorize("@ss.hasPermi('system:detail:edit')")
    @Log(title = "服务发放明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbGiveDetail tbGiveDetail)
    {
        return toAjax(tbGiveDetailService.updateTbGiveDetail(tbGiveDetail));
    }

    /**
     * 删除服务发放明细
     */
    @PreAuthorize("@ss.hasPermi('system:detail:remove')")
    @Log(title = "服务发放明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tbGiveDetailService.deleteTbGiveDetailByIds(ids));
    }
}
