package com.ruoyi.web.controller.business.giveRecord;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.giveRecord.TbGiveRecord;
import com.ruoyi.system.service.giveRecord.ITbGiveRecordService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 服务发放记录Controller
 * 
 * @author ruoyi
 * @date 2024-09-24
 */
@RestController
@RequestMapping("/system/record")
public class TbGiveRecordController extends BaseController
{
    @Autowired
    private ITbGiveRecordService tbGiveRecordService;

    /**
     * 查询服务发放记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:record:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbGiveRecord tbGiveRecord)
    {
        startPage();
        List<TbGiveRecord> list = tbGiveRecordService.selectTbGiveRecordList(tbGiveRecord);
        return getDataTable(list);
    }

    /**
     * 导出服务发放记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:record:export')")
    @Log(title = "服务发放记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbGiveRecord tbGiveRecord)
    {
        List<TbGiveRecord> list = tbGiveRecordService.selectTbGiveRecordList(tbGiveRecord);
        ExcelUtil<TbGiveRecord> util = new ExcelUtil<TbGiveRecord>(TbGiveRecord.class);
        util.exportExcel(response, list, "服务发放记录数据");
    }

    /**
     * 获取服务发放记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:record:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tbGiveRecordService.selectTbGiveRecordById(id));
    }

    /**
     * 新增服务发放记录
     */
    @PreAuthorize("@ss.hasPermi('system:record:add')")
    @Log(title = "服务发放记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbGiveRecord tbGiveRecord)
    {
        return toAjax(tbGiveRecordService.insertTbGiveRecord(tbGiveRecord));
    }

    /**
     * 修改服务发放记录
     */
    @PreAuthorize("@ss.hasPermi('system:record:edit')")
    @Log(title = "服务发放记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbGiveRecord tbGiveRecord)
    {
        return toAjax(tbGiveRecordService.updateTbGiveRecord(tbGiveRecord));
    }

    /**
     * 删除服务发放记录
     */
    @PreAuthorize("@ss.hasPermi('system:record:remove')")
    @Log(title = "服务发放记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tbGiveRecordService.deleteTbGiveRecordByIds(ids));
    }
}
