package com.ruoyi.web.controller.business.my;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.my.MOrders;
import com.ruoyi.system.service.my.IMOrdersService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 我得订单Controller
 * 
 * @author ruoyi
 * @date 2024-09-30
 */
@RestController
@RequestMapping("/myOrders")
public class MOrdersController extends BaseController
{
    @Autowired
    private IMOrdersService mOrdersService;

    /**
     * 查询我得订单列表
     */
    @PreAuthorize("@ss.hasPermi('my:orders:list')")
    @PostMapping("/list")
    public TableDataInfo list(@RequestBody MOrders mOrders)
    {
        startPage();
        List<MOrders> list = mOrdersService.selectMOrdersList(mOrders);
        return getDataTable(list);
    }

    /**
     * 导出我得订单列表
     */
    @PreAuthorize("@ss.hasPermi('my:orders:export')")
    @Log(title = "我得订单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MOrders mOrders)
    {
        List<MOrders> list = mOrdersService.selectMOrdersList(mOrders);
        ExcelUtil<MOrders> util = new ExcelUtil<MOrders>(MOrders.class);
        util.exportExcel(response, list, "我得订单数据");
    }


    /**
     * 获取我得订单详细信息
     */
    @PreAuthorize("@ss.hasPermi('my:orders:query')")
    @GetMapping(value = "getMUserId")
    public AjaxResult getMUserId()
    {
        return success(mOrdersService.selectMOrdersByMUserId());
    }


    /**
     * 获取我得订单详细信息
     */
    @PreAuthorize("@ss.hasPermi('my:orders:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(mOrdersService.selectMOrdersById(id));
    }

    /**
     * 新增我得订单
     */
    @PreAuthorize("@ss.hasPermi('my:orders:add')")
    @Log(title = "我得订单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MOrders mOrders)
    {
        return toAjax(mOrdersService.insertMOrders(mOrders));
    }

    /**
     * 修改我得订单
     */
    @PreAuthorize("@ss.hasPermi('my:orders:edit')")
    @Log(title = "我得订单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MOrders mOrders)
    {
        return toAjax(mOrdersService.updateMOrders(mOrders));
    }

    /**
     * 删除我得订单
     */
    @PreAuthorize("@ss.hasPermi('my:orders:remove')")
    @Log(title = "我得订单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mOrdersService.deleteMOrdersByIds(ids));
    }
}
