package com.ruoyi.web.controller.business.my;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.my.MOrdersFile;
import com.ruoyi.system.service.my.IMOrdersFileService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 我得订单 附件Controller
 * 
 * @author ruoyi
 * @date 2024-09-30
 */
@RestController
@RequestMapping("/myOrders/file")
public class MOrdersFileController extends BaseController
{
    @Autowired
    private IMOrdersFileService mOrdersFileService;

    /**
     * 查询我得订单 附件列表
     */
    @PreAuthorize("@ss.hasPermi('myOrders:file:list')")
    @GetMapping("/list")
    public TableDataInfo list(MOrdersFile mOrdersFile)
    {
        startPage();
        List<MOrdersFile> list = mOrdersFileService.selectMOrdersFileList(mOrdersFile);
        return getDataTable(list);
    }

    /**
     * 导出我得订单 附件列表
     */
    @PreAuthorize("@ss.hasPermi('myOrders:file:export')")
    @Log(title = "我得订单 附件", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MOrdersFile mOrdersFile)
    {
        List<MOrdersFile> list = mOrdersFileService.selectMOrdersFileList(mOrdersFile);
        ExcelUtil<MOrdersFile> util = new ExcelUtil<MOrdersFile>(MOrdersFile.class);
        util.exportExcel(response, list, "我得订单 附件数据");
    }

    /**
     * 获取我得订单 附件详细信息
     */
    @PreAuthorize("@ss.hasPermi('myOrders:file:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(mOrdersFileService.selectMOrdersFileById(id));
    }

    /**
     * 新增我得订单 附件
     */
    @PreAuthorize("@ss.hasPermi('myOrders:file:add')")
    @Log(title = "我得订单 附件", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MOrdersFile mOrdersFile)
    {
        return toAjax(mOrdersFileService.insertMOrdersFile(mOrdersFile));
    }

    /**
     * 修改我得订单 附件
     */
    @PreAuthorize("@ss.hasPermi('myOrders:file:edit')")
    @Log(title = "我得订单 附件", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MOrdersFile mOrdersFile)
    {
        return toAjax(mOrdersFileService.updateMOrdersFile(mOrdersFile));
    }

    /**
     * 删除我得订单 附件
     */
    @PreAuthorize("@ss.hasPermi('myOrders:file:remove')")
    @Log(title = "我得订单 附件", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mOrdersFileService.deleteMOrdersFileByIds(ids));
    }
}
