package com.ruoyi.web.controller.business.my;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.my.MSkill;
import com.ruoyi.system.service.my.IMSkillService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 我得技能Controller
 * 
 * @author ruoyi
 * @date 2024-09-30
 */
@RestController
@RequestMapping("/mySkill")
public class MSkillController extends BaseController
{
    @Autowired
    private IMSkillService mSkillService;

    /**
     * 查询我得技能列表
     */
    @PreAuthorize("@ss.hasPermi('my:skill:list')")
    @GetMapping("/list")
    public TableDataInfo list(MSkill mSkill)
    {
        startPage();
        List<MSkill> list = mSkillService.selectMSkillList(mSkill);
        return getDataTable(list);
    }

    /**
     * 导出我得技能列表
     */
    @PreAuthorize("@ss.hasPermi('my:skill:export')")
    @Log(title = "我得技能", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MSkill mSkill)
    {
        List<MSkill> list = mSkillService.selectMSkillList(mSkill);
        ExcelUtil<MSkill> util = new ExcelUtil<MSkill>(MSkill.class);
        util.exportExcel(response, list, "我得技能数据");
    }


    /**
     * 获取我得技能详细信息
     */
    @PreAuthorize("@ss.hasPermi('my:skill:query')")
    @GetMapping(value = "getInfoSkills")
    public AjaxResult getInfoSkills()
    {
        return success(mSkillService.getInfoSkills());
    }


    /**
     * 获取我得技能详细信息
     */
    @PreAuthorize("@ss.hasPermi('my:skill:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(mSkillService.selectMSkillById(id));
    }

    /**
     * 新增我得技能
     */
    @PreAuthorize("@ss.hasPermi('my:skill:add')")
    @Log(title = "我得技能", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MSkill mSkill)
    {
        return toAjax(mSkillService.insertMSkill(mSkill));
    }

    /**
     * 修改我得技能
     */
    @PreAuthorize("@ss.hasPermi('my:skill:edit')")
    @Log(title = "我得技能", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MSkill mSkill)
    {
        return toAjax(mSkillService.updateMSkill(mSkill));
    }

    /**
     * 删除我得技能
     */
    @PreAuthorize("@ss.hasPermi('my:skill:remove')")
    @Log(title = "我得技能", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mSkillService.deleteMSkillByIds(ids));
    }
}
