package com.ruoyi.web.controller.business.my;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.my.MUser;
import com.ruoyi.system.service.my.IMUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 我的灵活从业者Controller
 * 
 * @author ruoyi
 * @date 2024-09-30
 */
@RestController
@RequestMapping("/myUser/flexibleUsers")
public class MUserController extends BaseController
{
    @Autowired
    private IMUserService mUserService;

    /**
     * 查询我的灵活从业者列表
     */
    @PreAuthorize("@ss.hasPermi('my:user:list')")
    @GetMapping("/list")
    public TableDataInfo list(MUser mUser)
    {
        startPage();
        List<MUser> list = mUserService.selectMUserList(mUser);
        return getDataTable(list);
    }

    /**
     * 导出我的灵活从业者列表
     */
    @PreAuthorize("@ss.hasPermi('my:user:export')")
    @Log(title = "我的灵活从业者", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MUser mUser)
    {
        List<MUser> list = mUserService.selectMUserList(mUser);
        ExcelUtil<MUser> util = new ExcelUtil<MUser>(MUser.class);
        util.exportExcel(response, list, "我的灵活从业者数据");
    }


    /**
     * 获取我的灵活从业者详细信息
     */
    @PreAuthorize("@ss.hasPermi('my:user:query')")
    @GetMapping(value = "getMyInfo")
    public AjaxResult getMyInfo()
    {
        return success(mUserService.getMyInfo());
    }



    /**
     * 获取我的灵活从业者详细信息
     */
    @PreAuthorize("@ss.hasPermi('my:user:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(mUserService.selectMUserById(id));
    }

    /**
     * 新增我的灵活从业者
     */
    @PreAuthorize("@ss.hasPermi('my:user:add')")
    @Log(title = "我的灵活从业者", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MUser mUser)
    {
        return toAjax(mUserService.insertMUser(mUser));
    }

    /**
     * 修改我的灵活从业者
     */
    @PreAuthorize("@ss.hasPermi('my:user:edit')")
    @Log(title = "我的灵活从业者", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MUser mUser)
    {
        return toAjax(mUserService.updateMUser(mUser));
    }

    /**
     * 删除我的灵活从业者
     */
    @PreAuthorize("@ss.hasPermi('my:user:remove')")
    @Log(title = "我的灵活从业者", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mUserService.deleteMUserByIds(ids));
    }
}
