package com.ruoyi.web.controller.business.orderInformation;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.fastjson2.JSON;
import lombok.extern.slf4j.Slf4j;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.orderInformation.TbOrderInformation;
import com.ruoyi.system.service.orderInformation.ITbOrderInformationService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 订单信息Controller
 * 
 * @author ruoyi
 * @date 2024-09-25
 */
@Slf4j
@RestController
@RequestMapping("/system/order/information")
public class TbOrderInformationController extends BaseController
{
    @Autowired
    private ITbOrderInformationService tbOrderInformationService;

    /**
     * 查询订单信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:orderinformation:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbOrderInformation tbOrderInformation)
    {
        startPage();
        List<TbOrderInformation> list = tbOrderInformationService.selectTbOrderInformationList(tbOrderInformation);
        return getDataTable(list);
    }

    /**
     * 导出订单信息列表
     */
    @PreAuthorize("@ss.hasPermi('system:orderinformation:export')")
    @Log(title = "订单信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbOrderInformation tbOrderInformation)
    {
        log.info("导出订单信息列表入参:{}", JSON.toJSON(tbOrderInformation));
        List<TbOrderInformation> list = tbOrderInformationService.selectTbOrderInformationList(tbOrderInformation);
        ExcelUtil<TbOrderInformation> util = new ExcelUtil<TbOrderInformation>(TbOrderInformation.class);
        util.exportExcel(response, list, "订单信息数据");
    }

    /**
     * 获取订单信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:orderinformation:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tbOrderInformationService.selectTbOrderInformationById(id));
    }

    /**
     * 新增订单信息
     */
    @PreAuthorize("@ss.hasPermi('system:orderinformation:add')")
    @Log(title = "订单信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbOrderInformation tbOrderInformation)
    {
        return toAjax(tbOrderInformationService.insertTbOrderInformation(tbOrderInformation));
    }

    /**
     * 修改订单信息
     */
    @PreAuthorize("@ss.hasPermi('system:orderinformation:edit')")
    @Log(title = "订单信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbOrderInformation tbOrderInformation)
    {
        return toAjax(tbOrderInformationService.updateTbOrderInformation(tbOrderInformation));
    }

    /**
     * 删除订单信息
     */
    @PreAuthorize("@ss.hasPermi('system:orderinformation:remove')")
    @Log(title = "订单信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tbOrderInformationService.deleteTbOrderInformationByIds(ids));
    }
}
