package com.ruoyi.web.controller.business.projectType;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.projectType.TbProjectType;
import com.ruoyi.system.service.projectType.ITbProjectTypeService;
import com.ruoyi.common.utils.poi.ExcelUtil;

/**
 * 服务项目分类Controller
 * 
 * @author ruoyi
 * @date 2024-09-27
 */
@RestController
@RequestMapping("/system/type")
public class TbProjectTypeController extends BaseController
{
    @Autowired
    private ITbProjectTypeService tbProjectTypeService;

    /**
     * 查询服务项目分类列表
     */
    @PreAuthorize("@ss.hasPermi('system:type:list')")
    @GetMapping("/list")
    public AjaxResult list()
    {
        return success(tbProjectTypeService.selectAll());
    }

    /**
     * 导出服务项目分类列表
     */
    @PreAuthorize("@ss.hasPermi('system:type:export')")
    @Log(title = "服务项目分类", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbProjectType tbProjectType)
    {
        List<TbProjectType> list = tbProjectTypeService.selectTbProjectTypeList(tbProjectType);
        ExcelUtil<TbProjectType> util = new ExcelUtil<TbProjectType>(TbProjectType.class);
        util.exportExcel(response, list, "服务项目分类数据");
    }

    /**
     * 获取服务项目分类详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:type:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tbProjectTypeService.selectTbProjectTypeById(id));
    }

    /**
     * 新增服务项目分类
     */
    @PreAuthorize("@ss.hasPermi('system:type:add')")
    @Log(title = "服务项目分类", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbProjectType tbProjectType)
    {
        return toAjax(tbProjectTypeService.insertTbProjectType(tbProjectType));
    }

    /**
     * 修改服务项目分类
     */
    @PreAuthorize("@ss.hasPermi('system:type:edit')")
    @Log(title = "服务项目分类", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbProjectType tbProjectType)
    {
        return toAjax(tbProjectTypeService.updateTbProjectType(tbProjectType));
    }

    /**
     * 删除服务项目分类
     */
    @PreAuthorize("@ss.hasPermi('system:type:remove')")
    @Log(title = "服务项目分类", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tbProjectTypeService.deleteTbProjectTypeByIds(ids));
    }
}
