package com.ruoyi.web.controller.business.serProject;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.serProjrct.TbSerProjects;
import com.ruoyi.system.service.serProject.ITbSerProjectsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 服务项目Controller
 * 
 * @author ruoyi
 * @date 2024-09-23
 */
@RestController
@RequestMapping("/system/projects")
public class TbSerProjectsController extends BaseController
{
    @Autowired
    private ITbSerProjectsService tbSerProjectsService;

    /**
     * 查询服务项目列表
     */
    @PreAuthorize("@ss.hasPermi('system:projects:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbSerProjects tbSerProjects)
    {
        startPage();
        List<TbSerProjects> list = tbSerProjectsService.selectTbSerProjectsList(tbSerProjects);
        return getDataTable(list);
    }

    /**
     * 导出服务项目列表
     */
    @PreAuthorize("@ss.hasPermi('system:projects:export')")
    @Log(title = "服务项目", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TbSerProjects tbSerProjects)
    {
        List<TbSerProjects> list = tbSerProjectsService.selectTbSerProjectsList(tbSerProjects);
        ExcelUtil<TbSerProjects> util = new ExcelUtil<TbSerProjects>(TbSerProjects.class);
        util.exportExcel(response, list, "服务项目数据");
    }

    /**
     * 获取服务项目详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:projects:query')")
    @GetMapping(value = "/{itemName}")
    public AjaxResult getInfo(@PathVariable("itemName") String itemName)
    {
        return success(tbSerProjectsService.selectTbSerProjectsByItemName(itemName));
    }

    /**
     * 新增服务项目
     */
    @PreAuthorize("@ss.hasPermi('system:projects:add')")
    @Log(title = "服务项目", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbSerProjects tbSerProjects)
    {
        return toAjax(tbSerProjectsService.insertTbSerProjects(tbSerProjects));
    }

    /**
     * 修改服务项目
     */
    @PreAuthorize("@ss.hasPermi('system:projects:edit')")
    @Log(title = "服务项目", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbSerProjects tbSerProjects)
    {
        return toAjax(tbSerProjectsService.updateTbSerProjects(tbSerProjects));
    }

    /**
     * 修改服务项目状态
     */
    @PreAuthorize("@ss.hasPermi('system:projects:update')")
    @Log(title = "服务项目", businessType = BusinessType.UPDATE)
    @GetMapping("/update/state/{id}/{pageState}")
    public AjaxResult updateState(@PathVariable("id") String id, @PathVariable("pageState") String pageState)
    {
        return toAjax(tbSerProjectsService.updateState(id, pageState));
    }

    /**
     * 删除服务项目
     */
    @PreAuthorize("@ss.hasPermi('system:projects:remove')")
    @Log(title = "服务项目", businessType = BusinessType.DELETE)
	@DeleteMapping("/{id}")
    public AjaxResult remove(@PathVariable String[] id)
    {
        return toAjax(tbSerProjectsService.deleteTbSerProjectsByItemNames(id));
    }
}
