package com.ruoyi.web.controller.business.shop;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.shop.SAcceptOrders;
import com.ruoyi.system.domain.shop.SOrdersFile;
import com.ruoyi.system.service.shop.SAcceptOrdersService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;

import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 商家接单Controller
 * 
 * @author ruoyi
 * @date 2024-09-27
 */
@RestController
@RequestMapping("/shop/orders")
public class SAcceptOrdersController extends BaseController
{
    @Autowired
    private SAcceptOrdersService acceptOrdersService;

    /**
     * 查询商家接单列表
     */
    @PreAuthorize("@ss.hasPermi('system:orders:list')")
    @GetMapping("/list")
    public TableDataInfo list(SAcceptOrders sAcceptOrders)
    {
        startPage();
        List<SAcceptOrders> list = acceptOrdersService.selectTbAcceptOrdersList(sAcceptOrders);
        return getDataTable(list);
    }

    /**
     * 导出商家接单列表
     */
    @PreAuthorize("@ss.hasPermi('system:orders:export')")
    @Log(title = "商家接单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SAcceptOrders sAcceptOrders)
    {
        List<SAcceptOrders> list = acceptOrdersService.selectTbAcceptOrdersList(sAcceptOrders);
        ExcelUtil<SAcceptOrders> util = new ExcelUtil<>(SAcceptOrders.class);
        util.exportExcel(response, list, "商家接单数据");
    }

    /**
     * 获取商家接单详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:orders:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(acceptOrdersService.selectTbAcceptOrdersById(id));
    }

    /**
     * 新增商家接单
     */
    @PreAuthorize("@ss.hasPermi('system:orders:add')")
    @Log(title = "商家接单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SAcceptOrders sAcceptOrders)
    {
        return toAjax(acceptOrdersService.insertTbAcceptOrders(sAcceptOrders));
    }

    /**
     * 修改商家接单
     */
    @PreAuthorize("@ss.hasPermi('system:orders:edit')")
    @Log(title = "商家接单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SAcceptOrders sAcceptOrders)
    {
        return toAjax(acceptOrdersService.updateTbAcceptOrders(sAcceptOrders));
    }

    /**
     * 删除商家接单
     */
    @PreAuthorize("@ss.hasPermi('system:orders:remove')")
    @Log(title = "商家接单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(acceptOrdersService.deleteTbAcceptOrdersByIds(ids));
    }


    /**
     * 商家接单
     */
    @PreAuthorize("@ss.hasPermi('system:orders:query')")
    @GetMapping(value = "grabOrders/{orderId}/{businessId}")
    public AjaxResult grabOrders(@PathVariable("orderId") Long orderId,@PathVariable("businessId") Long businessId)
    {
        return acceptOrdersService.grabOrders(orderId, businessId);
    }



    /**
     * 商家取消订单
     */
    @PreAuthorize("@ss.hasPermi('system:orders:remove')")
    @GetMapping(value = "cancellationOrder/{id}")
    public AjaxResult cancellationOrder(@PathVariable("id") Long id)
    {
        return toAjax(acceptOrdersService.cancellationOrder(id));
    }



    /**
     * 凭证上传
     */
    @PreAuthorize("@ss.hasPermi('system:orders:add')")
    @PostMapping(value = "voucherUpload")
    public AjaxResult voucherUpload(SOrdersFile ordersFile)
    {
        return toAjax(acceptOrdersService.voucherUpload(ordersFile));
    }



}
