package com.ruoyi.web.controller.business.shop;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.shop.SShopFile;
import com.ruoyi.system.domain.shop.SShopInformation;
import com.ruoyi.system.service.shop.ISShopInformationService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 商家店铺信息Controller
 * 
 * @author ruoyi
 * @date 2024-10-10
 */
@RestController
@RequestMapping("/shop/information")
public class SShopInformationController extends BaseController
{
    @Autowired
    private ISShopInformationService sShopInformationService;

    /**
     * 查询商家店铺信息列表
     */
    @PreAuthorize("@ss.hasPermi('shop:information:list')")
    @GetMapping("/list")
    public TableDataInfo list(SShopInformation sShopInformation)
    {
        startPage();
        List<SShopInformation> list = sShopInformationService.selectSShopInformationList(sShopInformation);
        return getDataTable(list);
    }

    /**
     * 导出商家店铺信息列表
     */
    @PreAuthorize("@ss.hasPermi('shop:information:export')")
    @Log(title = "商家店铺信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SShopInformation sShopInformation)
    {
        List<SShopInformation> list = sShopInformationService.selectSShopInformationList(sShopInformation);
        ExcelUtil<SShopInformation> util = new ExcelUtil<SShopInformation>(SShopInformation.class);
        util.exportExcel(response, list, "商家店铺信息数据");
    }

    /**
     * 获取商家店铺信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('shop:information:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sShopInformationService.selectSShopInformationById(id));
    }

    /**
     * 新增商家店铺信息
     */
    @PreAuthorize("@ss.hasPermi('shop:information:add')")
    @Log(title = "商家店铺信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SShopInformation sShopInformation)
    {
        return toAjax(sShopInformationService.insertSShopInformation(sShopInformation));
    }

    /**
     * 修改商家店铺信息
     */
    @PreAuthorize("@ss.hasPermi('shop:information:edit')")
    @Log(title = "商家店铺信息", businessType = BusinessType.UPDATE)
    @PostMapping
    public AjaxResult edit(@RequestBody SShopInformation sShopInformation)
    {
        return toAjax(sShopInformationService.updateSShopInformation(sShopInformation));
    }

    /**
     * 删除商家店铺信息
     */
    @PreAuthorize("@ss.hasPermi('shop:information:remove')")
    @Log(title = "商家店铺信息", businessType = BusinessType.DELETE)
	@GetMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sShopInformationService.deleteSShopInformationByIds(ids));
    }


    /**
     * 保存服务环境附件
     *
     * @return
     */
    @PreAuthorize("@ss.hasPermi('shop:information:add')")
    @Log(title = "商家店铺信息", businessType = BusinessType.EXPORT)
    @PostMapping("/saveEnvironmentFiles")
    public AjaxResult saveEnvironmentFiles(@RequestBody List<SShopFile> shopFiles) {
        return toAjax(sShopInformationService.saveEnvironmentFiles(shopFiles));
    }





}
