package com.ruoyi.web.controller.business.shop;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.shop.SShopMaterial;
import com.ruoyi.system.service.shop.ISShopMaterialService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 商家素材图片上传Controller
 * 
 * @author ruoyi
 * @date 2024-10-09
 */
@RestController
@RequestMapping("/system/material")
public class SShopMaterialController extends BaseController
{
    @Autowired
    private ISShopMaterialService sShopMaterialService;

    /**
     * 查询商家素材图片上传列表
     */
    @PreAuthorize("@ss.hasPermi('system:material:list')")
    @GetMapping("/list")
    public TableDataInfo list(SShopMaterial sShopMaterial)
    {
        startPage();
        List<SShopMaterial> list = sShopMaterialService.selectSShopMaterialList(sShopMaterial);
        return getDataTable(list);
    }

    /**
     * 导出商家素材图片上传列表
     */
    @PreAuthorize("@ss.hasPermi('system:material:export')")
    @Log(title = "商家素材图片上传", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SShopMaterial sShopMaterial)
    {
        List<SShopMaterial> list = sShopMaterialService.selectSShopMaterialList(sShopMaterial);
        ExcelUtil<SShopMaterial> util = new ExcelUtil<SShopMaterial>(SShopMaterial.class);
        util.exportExcel(response, list, "商家素材图片上传数据");
    }

    /**
     * 获取商家素材图片上传详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:material:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sShopMaterialService.selectSShopMaterialById(id));
    }

    /**
     * 新增商家素材图片上传
     */
    @PreAuthorize("@ss.hasPermi('system:material:add')")
    @Log(title = "商家素材图片上传", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SShopMaterial sShopMaterial)
    {
        return toAjax(sShopMaterialService.insertSShopMaterial(sShopMaterial));
    }

    /**
     * 修改商家素材图片上传
     */
    @PreAuthorize("@ss.hasPermi('system:material:edit')")
    @Log(title = "商家素材图片上传", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SShopMaterial sShopMaterial)
    {
        return toAjax(sShopMaterialService.updateSShopMaterial(sShopMaterial));
    }

    /**
     * 删除商家素材图片上传
     */
    @PreAuthorize("@ss.hasPermi('system:material:remove')")
    @Log(title = "商家素材图片上传", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sShopMaterialService.deleteSShopMaterialByIds(ids));
    }
}
