package com.ruoyi.web.controller.business.withdrawalRecord;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.withdrawalRecord.TWithdrawalRecord;
import com.ruoyi.system.service.withdrawalRecord.ITWithdrawalRecordService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 提现记录Controller
 * 
 * @author ruoyi
 * @date 2024-09-25
 */
@RestController
@RequestMapping("/system/withdrawal/record")
public class TWithdrawalRecordController extends BaseController
{
    @Autowired
    private ITWithdrawalRecordService tWithdrawalRecordService;

    /**
     * 查询提现记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:withdrawal:record:list')")
    @GetMapping("/list")
    public TableDataInfo list(TWithdrawalRecord tWithdrawalRecord)
    {
        startPage();
        List<TWithdrawalRecord> list = tWithdrawalRecordService.selectTWithdrawalRecordList(tWithdrawalRecord);
        return getDataTable(list);
    }

    /**
     * 导出提现记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:withdrawal:record:export')")
    @Log(title = "提现记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TWithdrawalRecord tWithdrawalRecord)
    {
        List<TWithdrawalRecord> list = tWithdrawalRecordService.selectTWithdrawalRecordList(tWithdrawalRecord);
        ExcelUtil<TWithdrawalRecord> util = new ExcelUtil<TWithdrawalRecord>(TWithdrawalRecord.class);
        util.exportExcel(response, list, "提现记录数据");
    }

    /**
     * 获取提现记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:withdrawal:record:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tWithdrawalRecordService.selectTWithdrawalRecordById(id));
    }

    /**
     * 新增提现记录
     */
    @PreAuthorize("@ss.hasPermi('system:withdrawal:record:add')")
    @Log(title = "提现记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TWithdrawalRecord tWithdrawalRecord)
    {
        return toAjax(tWithdrawalRecordService.insertTWithdrawalRecord(tWithdrawalRecord));
    }

    /**
     * 修改提现记录
     */
    @PreAuthorize("@ss.hasPermi('system:withdrawal:record:edit')")
    @Log(title = "提现记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TWithdrawalRecord tWithdrawalRecord)
    {
        return toAjax(tWithdrawalRecordService.updateTWithdrawalRecord(tWithdrawalRecord));
    }

    /**
     * 删除提现记录
     */
    @PreAuthorize("@ss.hasPermi('system:withdrawal:record:remove')")
    @Log(title = "提现记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tWithdrawalRecordService.deleteTWithdrawalRecordByIds(ids));
    }
}
