package com.ruoyi.system.service.giveDetail.impl;

import java.util.ArrayList;
import java.util.List;

import com.alibaba.fastjson2.JSON;
import com.ruoyi.common.enums.DesensitizationUtils;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.constant.OrderConstant;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.giveDetail.TbGiveDetailMapper;
import com.ruoyi.system.domain.giveDetail.TbGiveDetail;
import com.ruoyi.system.service.giveDetail.ITbGiveDetailService;

import static com.ruoyi.common.enums.StringConstant.*;

/**
 * 服务发放明细Service业务层处理
 *
 * @author ruoyi
 * @date 2024-09-24
 */
@Slf4j
@Service
public class TbGiveDetailServiceImpl implements ITbGiveDetailService {
    @Autowired
    private TbGiveDetailMapper tbGiveDetailMapper;





    /**
     * 查询服务发放明细
     *
     * @param id 服务发放明细主键
     * @return 服务发放明细
     */
    @Override
    public TbGiveDetail selectTbGiveDetailById(Long id) {
        return tbGiveDetailMapper.selectTbGiveDetailById(id);
    }

    /**
     * 查询服务发放明细列表
     *
     * @param tbGiveDetail 服务发放明细
     * @return 服务发放明细
     */
    @Override
    public List<TbGiveDetail> selectTbGiveDetailList(TbGiveDetail tbGiveDetail) {
        //提取页面查询时间的 开始和结束时间
        log.info("服务发放明细入参:{}", JSON.toJSON(tbGiveDetail));
        if (StringUtils.isNotEmpty(tbGiveDetail.getDataValue()) && tbGiveDetail.getDataValue().size() == 2) {
            tbGiveDetail.setStartTime(tbGiveDetail.getDataValue().get(0));
            tbGiveDetail.setEndTime(tbGiveDetail.getDataValue().get(1));
        }
        List<TbGiveDetail> detailList = new ArrayList<>();
        try{
            detailList = tbGiveDetailMapper.selectTbGiveDetailList(tbGiveDetail);
            log.info("服务发放明细数据库出参数:{}", JSON.toJSON(detailList));
        } catch (Exception e) {
            log.info("查询服务发放明细数据库报错!");
            log.error("查询服务发放明细数据库:{}", e);
        }
        if (StringUtils.isNull(detailList)) {
            return detailList;
        }
        for (TbGiveDetail giveDetail : detailList) {
            if (StringUtils.isNull(giveDetail)) {
                return detailList;
            }
            //姓名脱敏
            if (StringUtils.isNotEmpty(giveDetail.getUserName())) {
                String userName = DesensitizationUtils.desensitizedName(giveDetail.getUserName());
                giveDetail.setUserName(userName);
            }
            //车牌号脱敏
            if (StringUtils.isNotEmpty(giveDetail.getCarNum())) {
                String carNum = DesensitizationUtils.desensitizedCarNum(giveDetail.getCarNum());
                giveDetail.setCarNum(carNum);
            }
            //电话号脱敏
            if (StringUtils.isNotEmpty(giveDetail.getTelephone())) {
                String telephone = DesensitizationUtils.desensitizedPhoneNumber(giveDetail.getTelephone());
                giveDetail.setTelephone(telephone);
            }
            //订单状态码值转换
            if (StringUtils.isNotEmpty(giveDetail.getSerState())) {
                String serState = giveDetail.getSerState();
                if (STRING_1.equals(serState)) {
                    serState = OrderConstant.ACCEPT_ORDERS.getName();
                } else if (STRING_2.equals(serState)) {
                    serState = OrderConstant.IN_TASK.getName();
                } else if (STRING_3.equals(serState)) {
                    serState = OrderConstant.WAIT_FINISH.getName();
                } else if (STRING_4.equals(serState)) {
                    serState = OrderConstant.FINISH.getName();
                }
                giveDetail.setSerState(serState);
            }
        }
        log.info("服务发放明细出参:{}", JSON.toJSON(detailList));
        return detailList;
    }

    /**
     * 新增服务发放明细
     *
     * @param tbGiveDetail 服务发放明细
     * @return 结果
     */
    @Override
    public int insertTbGiveDetail(TbGiveDetail tbGiveDetail) {
        return tbGiveDetailMapper.insert(tbGiveDetail);
    }

    /**
     * 修改服务发放明细
     *
     * @param tbGiveDetail 服务发放明细
     * @return 结果
     */
    @Override
    public int updateTbGiveDetail(TbGiveDetail tbGiveDetail) {
        return tbGiveDetailMapper.updateTbGiveDetail(tbGiveDetail);
    }

    /**
     * 批量删除服务发放明细
     *
     * @param ids 需要删除的服务发放明细主键
     * @return 结果
     */
    @Override
    public int deleteTbGiveDetailByIds(Long[] ids) {
        return tbGiveDetailMapper.deleteTbGiveDetailByIds(ids);
    }

    /**
     * 删除服务发放明细信息
     *
     * @param id 服务发放明细主键
     * @return 结果
     */
    @Override
    public int deleteTbGiveDetailById(Long id) {
        return tbGiveDetailMapper.deleteTbGiveDetailById(id);
    }
}
