package com.ruoyi.system.service.giveRecord.impl;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Locale;

import com.alibaba.fastjson2.JSON;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.giveRecord.TbGiveRecordMapper;
import com.ruoyi.system.domain.giveRecord.TbGiveRecord;
import com.ruoyi.system.service.giveRecord.ITbGiveRecordService;

import javax.xml.crypto.Data;

/**
 * 服务发放记录Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-09-24
 */
@Slf4j
@Service
public class TbGiveRecordServiceImpl implements ITbGiveRecordService 
{
    @Autowired
    private TbGiveRecordMapper tbGiveRecordMapper;

    public static final String GIVE_SER_NOTES = "项服务";


    /**
     * 查询服务发放记录
     * 
     * @param id 服务发放记录主键
     * @return 服务发放记录
     */
    @Override
    public TbGiveRecord selectTbGiveRecordById(Long id)
    {
        return tbGiveRecordMapper.selectTbGiveRecordById(id);
    }

    /**
     * 查询服务发放记录列表
     * 
     * @param tbGiveRecord 服务发放记录
     * @return 服务发放记录
     */
    @Override
    public List<TbGiveRecord> selectTbGiveRecordList(TbGiveRecord tbGiveRecord)
    {
        log.info("服务发放记录入参:{}", JSON.toJSON(tbGiveRecord));
        //提取页面查询时间的 开始和结束时间
        if (StringUtils.isNotEmpty(tbGiveRecord.getDataValue()) && tbGiveRecord.getDataValue().size() == 2) {
            List<String> dataValue = tbGiveRecord.getDataValue();
                tbGiveRecord.setStartTime(dataValue.get(0));
                tbGiveRecord.setEndTime(dataValue.get(1));
        }
        List<TbGiveRecord> tbGiveRecords = new ArrayList<>();
        try {
            tbGiveRecords = tbGiveRecordMapper.selectTbGiveRecordList(tbGiveRecord);
            log.info("服务发放记录数据库出参数:{}", JSON.toJSON(tbGiveRecords));
        } catch (Exception e) {
            log.info("查询服务发放记录数据库报错!");
            log.error("查询服务发放记录数据库:{}", e);
        }
        if (StringUtils.isNull(tbGiveRecords)) {
            return tbGiveRecords;
        }
        for (TbGiveRecord giveRecord : tbGiveRecords) {
            if (StringUtils.isNull(giveRecord)) {
                return tbGiveRecords;
            }
            if (StringUtils.isNotEmpty(giveRecord.getGiveSer())) {
                StringBuffer giveSer = new StringBuffer();
                giveSer.append(giveRecord.getGiveSer()).append(GIVE_SER_NOTES);
                giveRecord.setGiveSer(giveSer.toString());
            }
        }
        log.info("服务发放记录出参:{}", JSON.toJSON(tbGiveRecords));
        return tbGiveRecords;
    }

    /**
     * 新增服务发放记录
     * 
     * @param tbGiveRecord 服务发放记录
     * @return 结果
     */
    @Override
    public int insertTbGiveRecord(TbGiveRecord tbGiveRecord)
    {
        log.info("新增服务发放记录入参:{}", JSON.toJSON(tbGiveRecord));
        return tbGiveRecordMapper.insert(tbGiveRecord);
    }

    /**
     * 修改服务发放记录
     * 
     * @param tbGiveRecord 服务发放记录
     * @return 结果
     */
    @Override
    public int updateTbGiveRecord(TbGiveRecord tbGiveRecord)
    {
        return tbGiveRecordMapper.updateTbGiveRecord(tbGiveRecord);
    }

    /**
     * 批量删除服务发放记录
     * 
     * @param ids 需要删除的服务发放记录主键
     * @return 结果
     */
    @Override
    public int deleteTbGiveRecordByIds(Long[] ids)
    {
        return tbGiveRecordMapper.deleteTbGiveRecordByIds(ids);
    }

    /**
     * 删除服务发放记录信息
     * 
     * @param id 服务发放记录主键
     * @return 结果
     */
    @Override
    public int deleteTbGiveRecordById(Long id)
    {
        return tbGiveRecordMapper.deleteTbGiveRecordById(id);
    }
}
