package com.ruoyi.system.service.my.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.my.MOrders;
import com.ruoyi.system.mapper.my.MOrdersMapper;
import com.ruoyi.system.service.my.IMOrdersService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;


/**
 * 我得订单Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-09-30
 */
@Service
public class MOrdersServiceImpl implements IMOrdersService
{
    @Autowired
    private MOrdersMapper mOrdersMapper;

    /**
     * 查询我得订单
     * 
     * @param id 我得订单主键
     * @return 我得订单
     */
    @Override
    public MOrders selectMOrdersById(Long id)
    {
        return mOrdersMapper.selectMOrdersById(id);
    }

    /**
     * 查询我得订单列表
     * 
     * @param mOrders 我得订单
     * @return 我得订单
     */
    @Override
    public List<MOrders> selectMOrdersList(MOrders mOrders) {
        mOrders.setMUserId(SecurityUtils.getUserId());
        return mOrdersMapper.selectMOrdersList(mOrders);
    }

    /**
     * 新增我得订单
     * 
     * @param mOrders 我得订单
     * @return 结果
     */
    @Override
    public int insertMOrders(MOrders mOrders)
    {
        mOrders.setCreateTime(DateUtils.getNowDate());
        return mOrdersMapper.insert(mOrders);
    }

    /**
     * 修改我得订单
     * 
     * @param mOrders 我得订单
     * @return 结果
     */
    @Override
    public int updateMOrders(MOrders mOrders)
    {
        mOrders.setUpdateTime(DateUtils.getNowDate());
        return mOrdersMapper.updateById(mOrders);
    }

    /**
     * 批量删除我得订单
     * 
     * @param ids 需要删除的我得订单主键
     * @return 结果
     */
    @Override
    public int deleteMOrdersByIds(Long[] ids)
    {
        return mOrdersMapper.deleteMOrdersByIds(ids);
    }

    /**
     * 删除我得订单信息
     * 
     * @param id 我得订单主键
     * @return 结果
     */
    @Override
    public int deleteMOrdersById(Long id)
    {
        return mOrdersMapper.deleteMOrdersById(id);
    }

    @Override
    public MOrders selectMOrdersByMUserId() {
        return mOrdersMapper.selectMOrdersByMUserId(SecurityUtils.getUserId());
    }
}
