package com.ruoyi.system.service.my.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.domain.my.MSkill;
import com.ruoyi.system.mapper.my.MSkillMapper;
import com.ruoyi.system.service.my.IMSkillService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;


/**
 * 我得技能Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-09-30
 */
@Service
public class MSkillServiceImpl implements IMSkillService
{
    @Autowired
    private MSkillMapper mSkillMapper;

    /**
     * 查询我得技能
     * 
     * @param id 我得技能主键
     * @return 我得技能
     */
    @Override
    public MSkill selectMSkillById(Long id)
    {
        return mSkillMapper.selectMSkillById(id);
    }

    /**
     * 查询我得技能列表
     * 
     * @param mSkill 我得技能
     * @return 我得技能
     */
    @Override
    public List<MSkill> selectMSkillList(MSkill mSkill)
    {
        return mSkillMapper.selectMSkillList(mSkill);
    }

    /**
     * 新增我得技能
     * 
     * @param mSkill 我得技能
     * @return 结果
     */
    @Override
    public int insertMSkill(MSkill mSkill) {
        if (null != mSkill.getId()){
            return mSkillMapper.updateById(mSkill);
        }
        mSkill.setMUserId(mSkillMapper.getUUserId(SecurityUtils.getUserId()));
        mSkill.setCreateTime(DateUtils.getNowDate());
        return mSkillMapper.insert(mSkill);
    }

    /**
     * 修改我得技能
     * 
     * @param mSkill 我得技能
     * @return 结果
     */
    @Override
    public int updateMSkill(MSkill mSkill)
    {
        mSkill.setUpdateTime(DateUtils.getNowDate());
        return mSkillMapper.updateById(mSkill);
    }

    /**
     * 批量删除我得技能
     * 
     * @param ids 需要删除的我得技能主键
     * @return 结果
     */
    @Override
    public int deleteMSkillByIds(Long[] ids)
    {
        return mSkillMapper.deleteMSkillByIds(ids);
    }

    /**
     * 删除我得技能信息
     * 
     * @param id 我得技能主键
     * @return 结果
     */
    @Override
    public int deleteMSkillById(Long id)
    {
        return mSkillMapper.deleteMSkillById(id);
    }

    @Override
    public MSkill getInfoSkills() {
        return  mSkillMapper.getInfoSkills(SecurityUtils.getUserId());
    }
}
