package com.ruoyi.system.service.orderInformation.impl;

import java.util.ArrayList;
import java.util.List;

import com.alibaba.fastjson2.JSON;
import com.ruoyi.common.enums.DesensitizationUtils;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.constant.OrderConstant;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.orderInformation.TbOrderInformationMapper;
import com.ruoyi.system.domain.orderInformation.TbOrderInformation;
import com.ruoyi.system.service.orderInformation.ITbOrderInformationService;

import static com.ruoyi.common.enums.StringConstant.*;

/**
 * 订单信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-09-25
 */
@Slf4j
@Service
public class TbOrderInformationServiceImpl implements ITbOrderInformationService 
{
    @Autowired
    private TbOrderInformationMapper tbOrderInformationMapper;

    public static final String SER_PROOF_NOTES = "张";
    public static final String SER_PROOF_NULL = "未上传";



    /**
     * 查询订单信息
     * 
     * @param id 订单信息主键
     * @return 订单信息
     */
    @Override
    public TbOrderInformation selectTbOrderInformationById(Long id)
    {
        return tbOrderInformationMapper.selectTbOrderInformationById(id);
    }

    /**
     * 查询订单信息列表
     * 
     * @param tbOrderInformation 订单信息
     * @return 订单信息
     */
    @Override
    public List<TbOrderInformation> selectTbOrderInformationList(TbOrderInformation tbOrderInformation)
    {
        log.info("订单信息入参:{}", JSON.toJSON(tbOrderInformation));
        //提取页面查询时间的 开始和结束时间
        if (StringUtils.isNotEmpty(tbOrderInformation.getDataValue()) && tbOrderInformation.getDataValue().size() == 2) {
            tbOrderInformation.setStartTime(tbOrderInformation.getDataValue().get(0));
            tbOrderInformation.setEndTime(tbOrderInformation.getDataValue().get(1));
        }
        List<TbOrderInformation> tbOrderInformationList = new ArrayList<>();
        try {
            tbOrderInformationList = tbOrderInformationMapper.selectTbOrderInformationList(tbOrderInformation);
            log.info("订单信息数据库出参:{}", JSON.toJSON(tbOrderInformationList));
        } catch (Exception e) {
            log.info("查询订单信息数据库报错!");
            log.error("查询订单信息数据库:{}", e);
        }
        if (StringUtils.isNull(tbOrderInformationList)) {
            return tbOrderInformationList;
        }
        for (TbOrderInformation orderInformation : tbOrderInformationList) {
            if (StringUtils.isNull(orderInformation)) {
                return tbOrderInformationList;
            }
            //姓名脱敏
            if (StringUtils.isNotEmpty(orderInformation.getUserName())) {
                String userName = DesensitizationUtils.desensitizedName(orderInformation.getUserName());
                orderInformation.setUserName(userName);
            }
            //车牌号脱敏
            if (StringUtils.isNotEmpty(orderInformation.getCarNum())) {
                String carNum = DesensitizationUtils.desensitizedCarNum(orderInformation.getCarNum());
                orderInformation.setCarNum(carNum);
            }
            //手机号脱敏
            if (StringUtils.isNotEmpty(orderInformation.getTelephone())) {
                String telephone = DesensitizationUtils.desensitizedPhoneNumber(orderInformation.getTelephone());
                orderInformation.setTelephone(telephone);
            }
            //订单状态码值转换
            if (StringUtils.isNotEmpty(orderInformation.getSerState())) {
                String serState = orderInformation.getSerState();
                if (STRING_1.equals(serState)) {
                    serState = OrderConstant.ACCEPT_ORDERS.getName();
                } else if (STRING_2.equals(serState)) {
                    serState = OrderConstant.IN_TASK.getName();
                } else if (STRING_3.equals(serState)) {
                    serState = OrderConstant.WAIT_FINISH.getName();
                } else if (STRING_4.equals(serState)) {
                    serState = OrderConstant.FINISH.getName();
                }
                orderInformation.setSerState(serState);
            }
            if (StringUtils.isNotEmpty(orderInformation.getSerProof())) {
                StringBuffer serProof = new StringBuffer();
                serProof.append(orderInformation.getSerProof()).append(SER_PROOF_NOTES);
                orderInformation.setSerProof(serProof.toString());
            } else {
                StringBuffer serProof = new StringBuffer();
                serProof.append(SER_PROOF_NULL);
                orderInformation.setSerProof(serProof.toString());
            }
        }
        log.info("订单信息出参:{}", JSON.toJSON(tbOrderInformationList));
        return tbOrderInformationList;
    }

    /**
     * 新增订单信息
     * 
     * @param tbOrderInformation 订单信息
     * @return 结果
     */
    @Override
    public int insertTbOrderInformation(TbOrderInformation tbOrderInformation)
    {
        return tbOrderInformationMapper.insert(tbOrderInformation);
    }

    /**
     * 修改订单信息
     * 
     * @param tbOrderInformation 订单信息
     * @return 结果
     */
    @Override
    public int updateTbOrderInformation(TbOrderInformation tbOrderInformation)
    {
        return tbOrderInformationMapper.updateTbOrderInformation(tbOrderInformation);
    }

    /**
     * 批量删除订单信息
     * 
     * @param ids 需要删除的订单信息主键
     * @return 结果
     */
    @Override
    public int deleteTbOrderInformationByIds(Long[] ids)
    {
        return tbOrderInformationMapper.deleteTbOrderInformationByIds(ids);
    }

    /**
     * 删除订单信息信息
     * 
     * @param id 订单信息主键
     * @return 结果
     */
    @Override
    public int deleteTbOrderInformationById(Long id)
    {
        return tbOrderInformationMapper.deleteTbOrderInformationById(id);
    }

    @Override
    public TbOrderInformation selectTbOrderInformationByOrderNum(String orderNum) {
        return tbOrderInformationMapper.selectTbOrderInformationByOrderNum(orderNum);
    }
}
