package com.ruoyi.system.service.serProject.impl;

import java.util.ArrayList;
import java.util.List;

import com.alibaba.fastjson2.JSON;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.constant.ProjectStateConstant;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.serProject.TbSerProjectsMapper;
import com.ruoyi.system.domain.serProjrct.TbSerProjects;
import com.ruoyi.system.service.serProject.ITbSerProjectsService;

import static com.ruoyi.common.enums.StringConstant.*;

/**
 * 服务项目Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-09-23
 */
@Slf4j
@Service
public class TbSerProjectsServiceImpl implements ITbSerProjectsService
{
    @Autowired
    private TbSerProjectsMapper tbSerProjectsMapper;




    /**
     * 查询服务项目
     * 
     * @param itemName 服务项目主键
     * @return 服务项目
     */
    @Override
    public TbSerProjects selectTbSerProjectsByItemName(String itemName)
    {
        return tbSerProjectsMapper.selectTbSerProjectsByItemName(itemName);
    }

    /**
     * 查询服务项目列表
     * 
     * @param tbSerProjects 服务项目
     * @return 服务项目
     */
    @Override
    public List<TbSerProjects> selectTbSerProjectsList(TbSerProjects tbSerProjects)
    {
        log.info("查询服务项目列表入参:{}", JSON.toJSON(tbSerProjects));
        List<TbSerProjects> tbSerProjectList = new ArrayList<>();
        try {
            tbSerProjectList = tbSerProjectsMapper.selectTbSerProjectsList(tbSerProjects);
            log.info("查询服务项目列表数据库出参:{}", JSON.toJSON(tbSerProjectList));
        } catch (Exception e) {
            log.info("查询服务项目列表数据库报错!");
            log.error("查询服务项目列表数据库:{}", e);
        }
        if (StringUtils.isNotNull(tbSerProjectList)) {
            for (TbSerProjects serProjects : tbSerProjectList) {
                if (StringUtils.isNotNull(serProjects)) {
                    String pageState = serProjects.getPageState();
                    String state1 = new String();
                    if (STRING_0.equals(pageState)) {
                        pageState = ProjectStateConstant.PORJECT_STATE_DISABLE.getName();
                        state1 = ProjectStateConstant.PORJECT_STATE_ENABLE.getName();
                    } else if (STRING_1.equals(pageState)) {
                        pageState = ProjectStateConstant.PORJECT_STATE_ENABLE.getName();
                        state1 = ProjectStateConstant.PORJECT_STATE_DISABLE.getName();
                    }
                    serProjects.setPageState(pageState);
                    serProjects.setState1(state1);
                }
            }
        }
        log.info("查询服务项目列表出参:{}", JSON.toJSON(tbSerProjectList));
        return tbSerProjectList;
    }

    /**
     * 新增服务项目
     * 
     * @param tbSerProjects 服务项目
     * @return 结果
     */
    @Override
    public int insertTbSerProjects(TbSerProjects tbSerProjects)
    {
        log.info("新增服务项目入参:{}", JSON.toJSON(tbSerProjects));
        return tbSerProjectsMapper.insert(tbSerProjects);
    }

    /**
     * 修改服务项目
     * 
     * @param tbSerProjects 服务项目
     * @return 结果
     */
    @Override
    public int updateTbSerProjects(TbSerProjects tbSerProjects)
    {
        log.info("修改服务项目入参:{}", JSON.toJSON(tbSerProjects));
        return tbSerProjectsMapper.updateTbSerProjects(tbSerProjects);
    }

    /**
     * 批量删除服务项目
     * 
     * @param id 需要删除的服务项目主键
     * @return 结果
     */
    @Override
    public int deleteTbSerProjectsByItemNames(String[] id)
    {
        log.info("删除服务项目信息入参:id:{}", id);
        return tbSerProjectsMapper.deleteTbSerProjectsByItemNames(id);
    }

    /**
     * 删除服务项目信息
     * 
     * @param itemName 服务项目主键
     * @return 结果
     */
    @Override
    public int deleteTbSerProjectsByItemName(String itemName)
    {
        return tbSerProjectsMapper.deleteTbSerProjectsByItemName(itemName);
    }

    /**
     * 修改服务项目状态
     * @param id
     * @param pageState
     * @return
     */
    @Override
    public int updateState(String id, String pageState) {
        log.info("修改服务项目状态入参:id:{}", id,",pageState:", pageState);
        if (StringUtils.isEmpty(pageState) || StringUtils.isEmpty(id)) {
            return 0;
        }
        if (ProjectStateConstant.PORJECT_STATE_DISABLE.getName().equals(pageState)) {
            pageState = STRING_1;
        } else if (ProjectStateConstant.PORJECT_STATE_ENABLE.getName().equals(pageState)) {
            pageState = STRING_0;
        }
        TbSerProjects tbSerProjects = new TbSerProjects();
        tbSerProjects.setId(Long.valueOf(id));
        tbSerProjects.setPageState(pageState);

        log.info("修改服务项目状态数据库入参:{}", JSON.toJSON(tbSerProjects));
        return tbSerProjectsMapper.updateState(tbSerProjects);
    }
}
