package com.ruoyi.system.service.shop.Impl;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.spring.SpringUtils;
import com.ruoyi.system.constant.RedisConstant;
import com.ruoyi.system.domain.orderInformation.TbOrderInformation;
import com.ruoyi.system.domain.shop.SAcceptOrders;
import com.ruoyi.system.domain.shop.SOrdersFile;
import com.ruoyi.system.mapper.shop.SAcceptOrdersMapper;
import com.ruoyi.system.mapper.shop.SOrdersFileMapper;
import com.ruoyi.system.service.orderInformation.ITbOrderInformationService;
import com.ruoyi.system.service.shop.SAcceptOrdersService;
import com.ruoyi.system.utils.OrderGrabbingUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;

/**
 * 商家接单Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-09-27
 */
@Service
public class SAcceptOrdersServiceImpl implements SAcceptOrdersService
{
    @Autowired
    private SAcceptOrdersMapper sAcceptOrdersMapper;

    @Resource
    private ITbOrderInformationService orderInformationService;

    @Resource
    private RedisCache redisCache;

    @Autowired
    private SOrdersFileMapper ordersFileMapper;

    /**
     * 查询商家接单
     * 
     * @param id 商家接单主键
     * @return 商家接单
     */
    @Override
    public SAcceptOrders selectTbAcceptOrdersById(Long id)
    {
        return sAcceptOrdersMapper.selectSAcceptOrdersById(id);
    }

    /**
     * 查询商家接单列表
     * 
     * @param sAcceptOrders 商家接单
     * @return 商家接单
     */
    @Override
    public List<SAcceptOrders> selectTbAcceptOrdersList(SAcceptOrders sAcceptOrders)
    {
        return sAcceptOrdersMapper.selectSAcceptOrdersList(sAcceptOrders);
    }

    /**
     * 新增商家接单
     * 
     * @param sAcceptOrders 商家接单
     * @return 结果
     */
    @Override
    public int insertTbAcceptOrders(SAcceptOrders sAcceptOrders)
    {
        sAcceptOrders.setCreateTime(DateUtils.getNowDate());
        int row = sAcceptOrdersMapper.insert(sAcceptOrders);
        if (0 > row){
            redisCache.setCacheObject(RedisConstant.ORDER_ACCEPT_MARK + sAcceptOrders.getId(), sAcceptOrders.getId());
        }
        return row;
    }

    /**
     * 修改商家接单
     * 
     * @param sAcceptOrders 商家接单
     * @return 结果
     */
    @Override
    public int updateTbAcceptOrders(SAcceptOrders sAcceptOrders)
    {
        sAcceptOrders.setUpdateTime(DateUtils.getNowDate());
        return sAcceptOrdersMapper.updateSAcceptOrders(sAcceptOrders);
    }

    /**
     * 批量删除商家接单
     * 
     * @param ids 需要删除的商家接单主键
     * @return 结果
     */
    @Override
    public int deleteTbAcceptOrdersByIds(Long[] ids)
    {
        return sAcceptOrdersMapper.deleteSAcceptOrdersByIds(ids);
    }

    /**
     * 删除商家接单信息
     * 
     * @param id 商家接单主键
     * @return 结果
     */
    @Override
    public int deleteTbAcceptOrdersById(Long id)
    {
        return sAcceptOrdersMapper.deleteSAcceptOrdersById(id);
    }

    @Override
    public AjaxResult grabOrders(Long orderId,Long businessId) {
        if (null == orderId){
            return AjaxResult.error("订单ID不能为空");
        }
        boolean ordered = SpringUtils.getBean(OrderGrabbingUtils.class).OrderGrabbingService(orderId,businessId);
        if (ordered){
            return AjaxResult.success("接单成功");
        }
        return AjaxResult.error("接单失败");
    }

    @Override
    public int cancellationOrder(Long id) {
        SAcceptOrders acceptOrders = sAcceptOrdersMapper.selectSAcceptOrdersById(id);
        if (null == acceptOrders){
            return 0;
        }
        TbOrderInformation orderInformation = orderInformationService.selectTbOrderInformationByOrderNum(acceptOrders.getOrderNum());
        if ("2".equals(orderInformation.getSerState())){
            orderInformation.setSerState("1");
            orderInformationService.updateTbOrderInformation(orderInformation);
            redisCache.setCacheObject(RedisConstant.ORDER_ACCEPT_MARK + orderInformation.getId(),acceptOrders.getId());
        }
        return sAcceptOrdersMapper.deleteSAcceptOrdersById(acceptOrders.getId());
    }

    @Override
    public int voucherUpload(SOrdersFile ordersFile) {
        if (null == ordersFile.getAcceptOrdersId() || StringUtils.isEmpty(ordersFile.getUrl())){
            throw new ServiceException("业务主键不能为空");
        }
        return ordersFileMapper.insert(ordersFile);
    }
}
