package com.ruoyi.system.service.shop.Impl;

import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.shop.SShopFile;
import com.ruoyi.system.domain.shop.SShopInformation;
import com.ruoyi.system.mapper.shop.SShopFileMapper;
import com.ruoyi.system.mapper.shop.SShopInformationMapper;
import com.ruoyi.system.service.shop.ISShopInformationService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.List;


/**
 * 商家店铺信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-10-10
 */
@Service
public class SShopInformationServiceImpl implements ISShopInformationService
{
    @Autowired
    private SShopInformationMapper sShopInformationMapper;

    @Autowired
    private SShopFileMapper shopFileMapper;

    /**
     * 查询商家店铺信息
     * 
     * @param id 商家店铺信息主键
     * @return 商家店铺信息
     */
    @Override
    public SShopInformation selectSShopInformationById(Long id)
    {
        return sShopInformationMapper.selectSShopInformationById(id);
    }

    /**
     * 查询商家店铺信息列表
     * 
     * @param sShopInformation 商家店铺信息
     * @return 商家店铺信息
     */
    @Override
    public List<SShopInformation> selectSShopInformationList(SShopInformation sShopInformation)
    {
        return sShopInformationMapper.selectSShopInformationList(sShopInformation);
    }

    /**
     * 新增商家店铺信息
     * 
     * @param sShopInformation 商家店铺信息
     * @return 结果
     */
    @Override
    public int insertSShopInformation(SShopInformation sShopInformation)
    {
        sShopInformation.setCreateTime(DateUtils.getNowDate());
        return sShopInformationMapper.insert(sShopInformation);
    }

    /**
     * 修改商家店铺信息
     * 
     * @param sShopInformation 商家店铺信息
     * @return 结果
     */
    @Override
    public int updateSShopInformation(SShopInformation sShopInformation)
    {
        sShopInformation.setUpdateTime(DateUtils.getNowDate());
        return sShopInformationMapper.updateById(sShopInformation);
    }

    /**
     * 批量删除商家店铺信息
     * 
     * @param ids 需要删除的商家店铺信息主键
     * @return 结果
     */
    @Override
    public int deleteSShopInformationByIds(Long[] ids)
    {
        return sShopInformationMapper.deleteSShopInformationByIds(ids);
    }

    /**
     * 删除商家店铺信息信息
     * 
     * @param id 商家店铺信息主键
     * @return 结果
     */
    @Override
    public int deleteSShopInformationById(Long id)
    {
        return sShopInformationMapper.deleteSShopInformationById(id);
    }

    @Override
    public int saveEnvironmentFiles(List<SShopFile> shopFiles) {
        if (CollectionUtils.isEmpty(shopFiles)){
            throw new ServiceException("保存数据不能为空");
        }
        int count = 0;
        for (SShopFile shopFile : shopFiles) {
            if (null == shopFile.getShopInformationId()){
                throw new ServiceException("保存附件业务主键不能为空");
            }
            shopFileMapper.insert(shopFile);
            count ++;
        }
        return count;
    }
}
