package com.ruoyi.system.service.withdrawalRecord.impl;

import java.util.ArrayList;
import java.util.List;

import com.alibaba.fastjson2.JSON;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.constant.ExtractConstant;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.withdrawalRecord.TWithdrawalRecordMapper;
import com.ruoyi.system.domain.withdrawalRecord.TWithdrawalRecord;
import com.ruoyi.system.service.withdrawalRecord.ITWithdrawalRecordService;

import static com.ruoyi.common.enums.StringConstant.*;

/**
 * 提现记录Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-09-25
 */
@Slf4j
@Service
public class TWithdrawalRecordServiceImpl implements ITWithdrawalRecordService 
{
    @Autowired
    private TWithdrawalRecordMapper tWithdrawalRecordMapper;

    /**
     * 查询提现记录
     * 
     * @param id 提现记录主键
     * @return 提现记录
     */
    @Override
    public TWithdrawalRecord selectTWithdrawalRecordById(Long id)
    {
        return tWithdrawalRecordMapper.selectTWithdrawalRecordById(id);
    }

    /**
     * 查询提现记录列表
     * 
     * @param tWithdrawalRecord 提现记录
     * @return 提现记录
     */
    @Override
    public List<TWithdrawalRecord> selectTWithdrawalRecordList(TWithdrawalRecord tWithdrawalRecord)
    {
        log.info("查询提现记录列表入参:{}", JSON.toJSON(tWithdrawalRecord));
        //提取页面查询时间 的开始和结束时间
        if (StringUtils.isNotEmpty(tWithdrawalRecord.getDataValue()) && tWithdrawalRecord.getDataValue().size() == 2) {
            tWithdrawalRecord.setStartTime(tWithdrawalRecord.getDataValue().get(0));
            tWithdrawalRecord.setEndTime(tWithdrawalRecord.getDataValue().get(1));
        }
        List<TWithdrawalRecord> tWithdrawalRecordList = new ArrayList<>();
        try {
            tWithdrawalRecordList = tWithdrawalRecordMapper.selectTWithdrawalRecordList(tWithdrawalRecord);
            log.info("查询提现记录列表数据库出参:{}", JSON.toJSON(tWithdrawalRecordList));
        } catch (Exception e) {
            log.info("查询提现记录列表数据库报错!");
            log.error("查询提现记录列表数据库:{}", e);
        }
        if (StringUtils.isNull(tWithdrawalRecordList)) {
            return tWithdrawalRecordList;
        }
        for (TWithdrawalRecord withdrawalRecord : tWithdrawalRecordList) {
            if (StringUtils.isNull(withdrawalRecord)) {
                return tWithdrawalRecordList;
            }
            //提现状态转换
            if (StringUtils.isNotEmpty(withdrawalRecord.getExtractStatus())) {
                String extractStatus = withdrawalRecord.getExtractStatus();
                if (STRING_1.equals(extractStatus)) {
                    extractStatus = ExtractConstant.EXTRACT_SUCCESS.getName();
                } else if (STRING_2.equals(extractStatus)) {
                    extractStatus = ExtractConstant.EXTRACT_FAIL.getName();
                } else if (STRING_3.equals(extractStatus)) {
                    extractStatus = ExtractConstant.EXTRACT_IN.getName();
                }
                withdrawalRecord.setExtractStatus(extractStatus);
            }
        }
        log.info("查询提现记录列表出参:{}", JSON.toJSON(tWithdrawalRecordList));
        return tWithdrawalRecordList;
    }

    /**
     * 新增提现记录
     * 
     * @param tWithdrawalRecord 提现记录
     * @return 结果
     */
    @Override
    public int insertTWithdrawalRecord(TWithdrawalRecord tWithdrawalRecord)
    {
        tWithdrawalRecord.setCreateTime(DateUtils.getNowDate());
        return tWithdrawalRecordMapper.insert(tWithdrawalRecord);
    }

    /**
     * 修改提现记录
     * 
     * @param tWithdrawalRecord 提现记录
     * @return 结果
     */
    @Override
    public int updateTWithdrawalRecord(TWithdrawalRecord tWithdrawalRecord)
    {
        tWithdrawalRecord.setUpdateTime(DateUtils.getNowDate());
        return tWithdrawalRecordMapper.updateTWithdrawalRecord(tWithdrawalRecord);
    }

    /**
     * 批量删除提现记录
     * 
     * @param ids 需要删除的提现记录主键
     * @return 结果
     */
    @Override
    public int deleteTWithdrawalRecordByIds(Long[] ids)
    {
        return tWithdrawalRecordMapper.deleteTWithdrawalRecordByIds(ids);
    }

    /**
     * 删除提现记录信息
     * 
     * @param id 提现记录主键
     * @return 结果
     */
    @Override
    public int deleteTWithdrawalRecordById(Long id)
    {
        return tWithdrawalRecordMapper.deleteTWithdrawalRecordById(id);
    }
}
