package com.ruoyi.system.utils;


import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.MessageUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.constant.RedisConstant;
import com.ruoyi.system.domain.orderInformation.TbOrderInformation;
import com.ruoyi.system.domain.shop.SAcceptOrders;
import com.ruoyi.system.mapper.shop.SShopInformationMapper;
import com.ruoyi.system.service.orderInformation.ITbOrderInformationService;
import com.ruoyi.system.service.shop.SAcceptOrdersService;
import org.redisson.api.RLock;
import org.redisson.api.RedissonClient;
import org.springframework.context.annotation.Configuration;

import javax.annotation.Resource;
import java.util.Date;
import java.util.concurrent.TimeUnit;

@Configuration
public class OrderGrabbingUtils {

    @Resource
    private RedissonClient redissonClient;

    @Resource
    private SAcceptOrdersService acceptOrdersService;

    @Resource
    private ITbOrderInformationService orderInformationService;

    @Resource
    private RedisCache redisCache;

    @Resource
    private SShopInformationMapper shopInformationMapper;

    /**
     *
     * @param orderId 订单ID
     * @param businessId 商家ID
     * @return
     */
    public boolean OrderGrabbingService(Long  orderId,Long businessId){

        //订单过来直接   把订单ID 写入redis
        //redisTemplate.opsForValue().set(RedisConstant.ORDER_ACCEPT_MARK + orderId,orderId);

        String redisKey = RedisConstant.ORDER_ACCEPT_MARK + orderId;
        if (!redisCache.hasKey(redisKey)) {
            // 抢单失败
            throw new ServiceException("订单不存在或已被他人接单",100);
        }
        // 创建锁
        RLock lock = redissonClient.getLock(RedisConstant.ROB_NEW_ORDER_LOCK + orderId);
        try {
            boolean flag = lock.tryLock(
                    RedisConstant.ROB_NEW_ORDER_LOCK_WAIT_TIME,
                    RedisConstant.ROB_NEW_ORDER_LOCK_LEASE_TIME,
                    TimeUnit.SECONDS
            );

            // 获取到锁  抢单成功的逻辑
            if (flag) {
                if (!redisCache.hasKey(redisKey)) {
                    // 抢单失败
                    throw new ServiceException(MessageUtils.message("user.not.exists"));
                }
                //   更新订单的状态为 已接单 。。 如果用户取消当前订单，在同时把订单写入到redis中进行抢单 。
                TbOrderInformation tbOrderInformation = orderInformationService.selectTbOrderInformationById(orderId);
                if (null == tbOrderInformation && StringUtils.equals(tbOrderInformation.getSerState(),"1")){
                    throw new ServiceException("订单不存在或已被他人接单");
                }
                int row = acceptOrdersService.insertTbAcceptOrders(createObject(tbOrderInformation, businessId));
                if (0 > row){
                    throw new ServiceException("抢单失败",100);
                }
                tbOrderInformation.setSerState("2");
                orderInformationService.updateTbOrderInformation(tbOrderInformation);
                // 更新订单成功时   删除Redis中的标示key
                redisCache.deleteObject(redisKey);
            }
        } catch (Exception e) {
            System.out.println("========" +e.getMessage());
        } finally {
            // 释放锁
            if (lock.isLocked()) {
                lock.unlock();
            }
        }
        return true;
    }


    public SAcceptOrders createObject (TbOrderInformation orderInformation, Long businessId){
        SAcceptOrders acceptOrders = new SAcceptOrders();
        acceptOrders.setOrderNum(orderInformation.getOrderNum());
        acceptOrders.setBusinessId(businessId);
        acceptOrders.setAcceptOrdersTime(new Date());
        acceptOrders.setSearchValue(shopInformationMapper.selectById(businessId).getStoreName());
        return acceptOrders;
    }


}
